### CMail::In::Base
# just provides a couple base methods for mailbox readers
package CMail::In::Base;

use Carp;

# constructor
sub new {
	my $proto	= shift;
	my $class	= ref($proto) || $proto;
	my $self	= {};
	bless($self,$class);

	$self->config(@_);

	return $self;
}

# methods
sub count {
	croak "Someone forgot to overload their count method.";
}

sub config {
	my $self = shift;
	my %info = @_;

	foreach my $key ( keys %info ) {
		$self->{$key} = $info{$key};
	}

	return;
}

# internal methods

# parse_uri - Parses out and returns the parts of the uri from the object's
#	config. In string context, return the path, in array context, returns
#	($user,$pass,$host,$port,$path)
sub parse_uri {
	my $self = shift;
	my $uri	= $self->{uri};

	if (wantarray) {	# do full extraction
		my @parts = ($uri =~ m{://([^:]+:[^@]+@)?([^/:]+)?(:\d+)?(/.*)?})
			or return undef;

		my($user,$pass) = ($parts[0] =~ /^(.*):(.*)\@$/);
		my $host = $parts[1];
		my $port = $parts[2];	$port =~ s/[^0-9]//g;
		my $path = $parts[3];

		return($user,$pass,$host,$port,$path);
	} else {			# do quick path extraction
		$uri =~ m{://[^/]*(/.*)} or return undef;
		my $path = $1;
		return $path;
	}
}

1;
